==> magics++_2.8.0.dfsg.orig.tar.gz: magics++-2.8.0.dfsg/src/visualisers/LookupTableMode.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file LookupTableMode.h
    \brief Definition of the Template class LookupTableMode.
    
    Magics Team - ECMWF 2005
    
    Started: Tue 17-May-2005
    
    Changes:
    
*/

#ifndef LookupTableMode_H
#define LookupTableMode_H

#include "magics.h"
#include "Translator.h"
#include "Factory.h"

#include "LookupTableModeAttributes.h"
#include "PaperPoint.h"
#include "Image.h"
#include "RasterData.h"

namespace magics {

class LookupTableMode: public LookupTableModeAttributes {

public:
	LookupTableMode();
	virtual ~LookupTableMode();
	virtual void set(const map<string, string>& map ) // for MagML
		 { LookupTableModeAttributes::set(map); }
    virtual void set(const XmlNode& node) // for MagML
		 { LookupTableModeAttributes::set(node); }
	virtual LookupTableMode* clone() const { 
		 LookupTableMode* object = new LookupTableMode();
		 object->copy(*this);
		 return object;
	}

	virtual void operator()(Image&, Raster&) {}

protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream&) const; 

private:
    //! Copy constructor - No copy allowed
	LookupTableMode(const LookupTableMode&);
    //! Overloaded << operator to copy - No copy allowed
	LookupTableMode& operator=(const LookupTableMode&);

// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const LookupTableMode& p)
		{ p.print(s); return s; }

};

template<>
class Translator<string, LookupTableMode> { 
public:
    LookupTableMode* operator()(const string& val ) {
		 return SimpleObjectMaker<LookupTableMode>::create(val);
	}     
    LookupTableMode* magics(const string& param)
    {
        LookupTableMode* object;
		ParameterManager::update(param, object);
		return object;
    }
};


} // namespace magics
#endif

==> magics++_2.10.0.dfsg.orig.tar.gz: magics++-2.10.0.dfsg/src/visualisers/LookupTableMode.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file LookupTableMode.h
    \brief Definition of the Template class LookupTableMode.
    
    Magics Team - ECMWF 2005
    
    Started: Tue 17-May-2005
    
    Changes:
    
*/

#ifndef LookupTableMode_H
#define LookupTableMode_H

#include "magics.h"
#include "Translator.h"
#include "Factory.h"

#include "LookupTableModeAttributes.h"
#include "FixedTableModeAttributes.h"
#include "PaperPoint.h"
#include "Image.h"
#include "RasterData.h"

namespace magics {

class LookupTableMode: public LookupTableModeAttributes {

public:
	LookupTableMode();
	virtual ~LookupTableMode();
	virtual void set(const map<string, string>& map ) // for MagML
		 { LookupTableModeAttributes::set(map); }
    virtual void set(const XmlNode& node) // for MagML
		 { LookupTableModeAttributes::set(node); }
	virtual LookupTableMode* clone() const { 
		 LookupTableMode* object = new LookupTableMode();
		 object->copy(*this);
		 return object;
	}

	virtual void operator()(Image&, Raster&) {}

protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream&) const; 

private:
    //! Copy constructor - No copy allowed
	LookupTableMode(const LookupTableMode&);
    //! Overloaded << operator to copy - No copy allowed
	LookupTableMode& operator=(const LookupTableMode&);

// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const LookupTableMode& p)
		{ p.print(s); return s; }

};

class FixedTableMode: public LookupTableMode,  FixedTableModeAttributes {

public:
	FixedTableMode();
	virtual ~FixedTableMode();
	void set(const map<string, string>& map ) // for MagML
	{
	   LookupTableMode::set(map); 
	  FixedTableModeAttributes::set(map);
	}
	void set(const XmlNode& node ) // for MagML
		{
		   LookupTableMode::set(node); 
		   FixedTableModeAttributes::set(node);
		}

	virtual void operator()(Image&, Raster&);

protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream&) const; 
	  //! Overloaded << operator to call print().
		friend ostream& operator<<(ostream& s,const FixedTableMode& p)
			{ p.print(s); return s; }
private:
   
};

template<>
class Translator<string, LookupTableMode> { 
public:
    LookupTableMode* operator()(const string& val ) {
		 return SimpleObjectMaker<LookupTableMode>::create(val);
	}     
    LookupTableMode* magics(const string& param)
    {
        LookupTableMode* object;
		ParameterManager::update(param, object);
		return object;
    }
};


} // namespace magics
#endif
